APIContact class

Represents contact information in the OpenAPI specification.

Inheritance

Constructors

APIContact()

Properties

castMap → Map<String, Cast>
no setterinherited
email ↔ String
getter/setter pair
extensions ↔ Map<String, dynamic>
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String
getter/setter pair
referenceURI ↔ Uri
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String
getter/setter pair

Methods

decode(KeyedArchive object) → void
override
encode(KeyedArchive object) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited