APIOperation class

Represents a HTTP operation (a path/method pair) in the OpenAPI specification.

Inheritance

Constructors

APIOperation()

Properties

castMap → Map<String, Cast>
no setteroverride
consumes ↔ List<String>
getter/setter pair
deprecated ↔ bool
getter/setter pair
description ↔ String
getter/setter pair
extensions ↔ Map<String, dynamic>
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
parameters ↔ List<APIParameter>
getter/setter pair
produces ↔ List<String>
getter/setter pair
referenceURI ↔ Uri
getter/setter pairinherited
responses ↔ Map<String, APIResponse>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemes ↔ List<String>
getter/setter pair
security ↔ List<Map<String, List<String>>>
getter/setter pair
summary ↔ String
getter/setter pair
tags ↔ List<String>
getter/setter pair

Methods

decode(KeyedArchive object) → void
override
encode(KeyedArchive object) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited