APIResponse class

Represents an HTTP response in the OpenAPI specification.

Inheritance

Constructors

APIResponse()

Properties

castMap → Map<String, Cast>
no setterinherited
description ↔ String
getter/setter pair
extensions ↔ Map<String, dynamic>
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ Map<String, APIHeader>
getter/setter pair
referenceURI ↔ Uri
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema ↔ APISchemaObject?
getter/setter pair

Methods

decode(KeyedArchive object) → void
override
encode(KeyedArchive object) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited