APIPath class

Describes the operations available on a single path.

An APIPath MAY be empty, due to ACL constraints. The path itself is still exposed to the documentation viewer but they will not know which operations and parameters are available.

Inheritance

Constructors

APIPath({String? summary, String? description, List<APIParameter>? parameters, Map<String, APIOperation>? operations})
APIPath.empty()

Properties

castMap → Map<String, Cast>
no setterinherited
description ↔ String?
An optional, string description, intended to apply to all operations in this path.
getter/setter pair
extensions ↔ Map<String, dynamic>
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
operations ↔ Map<String, APIOperation>?
Definitions of operations on this path.
getter/setter pair
parameters ↔ List<APIParameter>?
A list of parameters that are applicable for all the operations described under this path.
getter/setter pair
referenceURI ↔ Uri
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
summary ↔ String?
An optional, string summary, intended to apply to all operations in this path.
getter/setter pair

Methods

containsPathParameters(List<String> parameterNames) → bool
Returns true if this path has path parameters parameterNames.
decode(KeyedArchive object) → void
override
encode(KeyedArchive object) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited