APISecurityScheme class

Defines a security scheme that can be used by the operations.

Supported schemes are HTTP authentication, an API key (either as a header or as a query parameter), OAuth2's common flows (implicit, password, application and access code) as defined in RFC6749, and OpenID Connect Discovery.

Inheritance

Properties

castMap → Map<String, Cast>
no setterinherited
connectURL ↔ Uri?
OpenId Connect URL to discover OAuth2 configuration values.
getter/setter pair
description ↔ String?
A short description for security scheme. CommonMark syntax MAY be used for rich text representation.
getter/setter pair
extensions ↔ Map<String, dynamic>
getter/setter pairinherited
flows ↔ Map<String, APISecuritySchemeOAuth2Flow>?
An object containing configuration information for the flow types supported.
getter/setter pair
format ↔ String?
A hint to the client to identify how the bearer token is formatted.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
location ↔ APIParameterLocation?
The location of the API key.
getter/setter pair
name ↔ String?
The name of the header, query or cookie parameter to be used.
getter/setter pair
referenceURI ↔ Uri
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheme ↔ String?
The name of the HTTP Authorization scheme to be used in the Authorization header as defined in RFC7235.
getter/setter pair
type ↔ APISecuritySchemeType?
The type of the security scheme.
getter/setter pair

Methods

decode(KeyedArchive object) → void
override
encode(KeyedArchive object) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited